@@ -20,9 +20,11 @@ import json
 from copy import deepcopy
 from datetime import timedelta
 from typing import Any
-from unittest.mock import MagicMock, patch
+from unittest.mock import AsyncMock, MagicMock, patch
 
+import aiohttp
 import pytest
+from requests import exceptions as requests_exceptions
 from requests.models import Response
 
 from airflow.exceptions import AirflowException
@@ -36,7 +38,11 @@ from airflow.providers.dbt.cloud.hooks.dbt import (
     TokenAuth,
     fallback_to_default_account,
 )
-from airflow.utils import timezone
+
+try:
+    from airflow.sdk import timezone
+except ImportError:
+    from airflow.utils import timezone  # type: ignore[attr-defined,no-redef]
 
 ACCOUNT_ID_CONN = "account_id_conn"
 NO_ACCOUNT_ID_CONN = "no_account_id_conn"
@@ -57,6 +63,7 @@ RUN_ID = 5555
 
 BASE_URL = "https://cloud.getdbt.com/"
 SINGLE_TENANT_URL = "https://single.tenant.getdbt.com/"
+NOT_VAILD_DBT_STATUS = "not a valid DbtCloudJobRunStatus"
 
 DEFAULT_LIST_PROJECTS_RESPONSE = {
     "data": [
@@ -90,6 +97,12 @@ def mock_response_json(response: dict):
     return run_response
 
 
+def request_exception_with_status(status_code: int) -> requests_exceptions.HTTPError:
+    response = Response()
+    response.status_code = status_code
+    return requests_exceptions.HTTPError(response=response)
+
+
 class TestDbtCloudJobRunStatus:
     valid_job_run_statuses = [
         1,  # QUEUED
@@ -127,7 +140,7 @@ class TestDbtCloudJobRunStatus:
         ids=_get_ids(invalid_job_run_statuses),
     )
     def test_invalid_job_run_status(self, statuses):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match=NOT_VAILD_DBT_STATUS):
             DbtCloudJobRunStatus.check_is_valid(statuses)
 
     @pytest.mark.parametrize(
@@ -144,7 +157,7 @@ class TestDbtCloudJobRunStatus:
         ids=_get_ids(invalid_job_run_statuses),
     )
     def test_invalid_terminal_job_run_status(self, statuses):
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError, match=NOT_VAILD_DBT_STATUS):
             DbtCloudJobRunStatus.check_is_valid(statuses)
 
 
@@ -257,7 +270,7 @@ class TestDbtCloudHook:
     )
     @patch.object(DbtCloudHook, "run")
     @patch.object(DbtCloudHook, "_paginate")
-    def test_get_account(self, mock_http_run, mock_paginate, conn_id, account_id):
+    def test_get_account(self, mock_paginate, mock_http_run, conn_id, account_id):
         hook = DbtCloudHook(conn_id)
         hook.get_account(account_id=account_id)
 
@@ -1067,3 +1080,235 @@ class TestDbtCloudHook:
 
         assert status is False
         assert msg == "403:Authentication credentials were not provided"
+
+    @pytest.mark.parametrize(
+        argnames="timeout_seconds",
+        argvalues=[60, 180, 300],
+        ids=["60s", "180s", "300s"],
+    )
+    @patch.object(DbtCloudHook, "run_with_advanced_retry")
+    def test_timeout_passed_to_run_and_get_response(self, mock_run_with_retry, timeout_seconds):
+        """Test that timeout is passed to extra_options in _run_and_get_response."""
+        hook = DbtCloudHook(ACCOUNT_ID_CONN, timeout_seconds=timeout_seconds)
+        mock_run_with_retry.return_value = mock_response_json({"data": {"id": JOB_ID}})
+
+        hook.get_job(job_id=JOB_ID, account_id=DEFAULT_ACCOUNT_ID)
+
+        call_args = mock_run_with_retry.call_args
+        assert call_args is not None
+        extra_options = call_args.kwargs.get("extra_options")
+        assert extra_options is not None
+        assert extra_options["timeout"] == timeout_seconds
+
+    @pytest.mark.parametrize(
+        argnames="timeout_seconds",
+        argvalues=[60, 180, 300],
+        ids=["60s", "180s", "300s"],
+    )
+    @patch.object(DbtCloudHook, "run_with_advanced_retry")
+    def test_timeout_passed_to_paginate(self, mock_run_with_retry, timeout_seconds):
+        """Test that timeout is passed to extra_options in _paginate."""
+        hook = DbtCloudHook(ACCOUNT_ID_CONN, timeout_seconds=timeout_seconds)
+        mock_response = mock_response_json(
+            {
+                "data": [{"id": JOB_ID}],
+                "extra": {"filters": {"limit": 100}, "pagination": {"count": 1, "total_count": 1}},
+            }
+        )
+        mock_run_with_retry.return_value = mock_response
+
+        hook.list_jobs(account_id=DEFAULT_ACCOUNT_ID)
+
+        call_args = mock_run_with_retry.call_args
+        assert call_args is not None
+        extra_options = call_args.kwargs.get("extra_options")
+        assert extra_options is not None
+        assert extra_options["timeout"] == timeout_seconds
+
+    @pytest.mark.parametrize(
+        argnames="timeout_seconds",
+        argvalues=[60, 180, 300],
+        ids=["60s", "180s", "300s"],
+    )
+    @patch.object(DbtCloudHook, "run_with_advanced_retry")
+    def test_timeout_with_proxies(self, mock_run_with_retry, timeout_seconds):
+        """Test that both timeout and proxies are passed to extra_options."""
+        hook = DbtCloudHook(PROXY_CONN, timeout_seconds=timeout_seconds)
+        mock_run_with_retry.return_value = mock_response_json({"data": {"id": JOB_ID}})
+
+        hook.get_job(job_id=JOB_ID, account_id=DEFAULT_ACCOUNT_ID)
+
+        call_args = mock_run_with_retry.call_args
+        assert call_args is not None
+        extra_options = call_args.kwargs.get("extra_options")
+        assert extra_options is not None
+        assert extra_options["timeout"] == timeout_seconds
+        assert "proxies" in extra_options
+        assert extra_options["proxies"] == EXTRA_PROXIES["proxies"]
+
+    @pytest.mark.parametrize(
+        argnames="exception, expected",
+        argvalues=[
+            (requests_exceptions.ConnectionError(), True),
+            (requests_exceptions.Timeout(), True),
+            (request_exception_with_status(503), True),
+            (request_exception_with_status(429), True),
+            (request_exception_with_status(404), False),
+            (aiohttp.ClientResponseError(MagicMock(), (), status=500, message=""), True),
+            (aiohttp.ClientResponseError(MagicMock(), (), status=429, message=""), True),
+            (aiohttp.ClientResponseError(MagicMock(), (), status=400, message=""), False),
+            (aiohttp.ClientConnectorError(MagicMock(), OSError()), True),
+            (TimeoutError(), True),
+            (ValueError(), False),
+        ],
+        ids=[
+            "requests_connection_error",
+            "requests_timeout",
+            "requests_status_503",
+            "requests_status_429",
+            "requests_status_404",
+            "aiohttp_status_500",
+            "aiohttp_status_429",
+            "aiohttp_status_400",
+            "aiohttp_connector_error",
+            "timeout_error",
+            "value_error",
+        ],
+    )
+    def test_retryable_error(self, exception, expected):
+        assert DbtCloudHook._retryable_error(exception) is expected
+
+    @pytest.mark.asyncio
+    @pytest.mark.parametrize(
+        "error_factory, retry_qty, retry_delay",
+        [
+            (
+                lambda: aiohttp.ClientResponseError(
+                    request_info=AsyncMock(), history=(), status=500, message=""
+                ),
+                3,
+                0.1,
+            ),
+            (
+                lambda: aiohttp.ClientResponseError(
+                    request_info=AsyncMock(), history=(), status=429, message=""
+                ),
+                5,
+                0.1,
+            ),
+            (lambda: aiohttp.ClientConnectorError(AsyncMock(), OSError("boom")), 2, 0.1),
+            (lambda: TimeoutError(), 2, 0.1),
+        ],
+        ids=["aiohttp_500", "aiohttp_429", "connector_error", "timeout"],
+    )
+    @patch("airflow.providers.dbt.cloud.hooks.dbt.aiohttp.ClientSession.get")
+    async def test_get_job_details_retry_with_retryable_errors(
+        self, get_mock, error_factory, retry_qty, retry_delay
+    ):
+        hook = DbtCloudHook(ACCOUNT_ID_CONN, retry_limit=retry_qty, retry_delay=retry_delay)
+
+        def fail_cm():
+            cm = AsyncMock()
+            cm.__aenter__.side_effect = error_factory()
+            return cm
+
+        ok_resp = AsyncMock()
+        ok_resp.raise_for_status = MagicMock(return_value=None)
+        ok_resp.json = AsyncMock(return_value={"data": "Success"})
+        ok_cm = AsyncMock()
+        ok_cm.__aenter__.return_value = ok_resp
+        ok_cm.__aexit__.return_value = AsyncMock()
+
+        all_resp = [fail_cm() for _ in range(retry_qty - 1)]
+        all_resp.append(ok_cm)
+        get_mock.side_effect = all_resp
+
+        result = await hook.get_job_details(run_id=RUN_ID, account_id=None)
+
+        assert result == {"data": "Success"}
+        assert get_mock.call_count == retry_qty
+
+    @pytest.mark.asyncio
+    @pytest.mark.parametrize(
+        "error_factory, expected_exception",
+        [
+            (
+                lambda: aiohttp.ClientResponseError(
+                    request_info=AsyncMock(), history=(), status=404, message="Not Found"
+                ),
+                aiohttp.ClientResponseError,
+            ),
+            (
+                lambda: aiohttp.ClientResponseError(
+                    request_info=AsyncMock(), history=(), status=400, message="Bad Request"
+                ),
+                aiohttp.ClientResponseError,
+            ),
+            (lambda: ValueError("Invalid parameter"), ValueError),
+        ],
+        ids=["aiohttp_404", "aiohttp_400", "value_error"],
+    )
+    @patch("airflow.providers.dbt.cloud.hooks.dbt.aiohttp.ClientSession.get")
+    async def test_get_job_details_retry_with_non_retryable_errors(
+        self, get_mock, error_factory, expected_exception
+    ):
+        hook = DbtCloudHook(ACCOUNT_ID_CONN, retry_limit=3, retry_delay=0.1)
+
+        def fail_cm():
+            cm = AsyncMock()
+            cm.__aenter__.side_effect = error_factory()
+            return cm
+
+        get_mock.return_value = fail_cm()
+
+        with pytest.raises(expected_exception):
+            await hook.get_job_details(run_id=RUN_ID, account_id=None)
+
+        assert get_mock.call_count == 1
+
+    @pytest.mark.asyncio
+    @pytest.mark.parametrize(
+        argnames="error_factory, expected_exception",
+        argvalues=[
+            (
+                lambda: aiohttp.ClientResponseError(
+                    request_info=AsyncMock(), history=(), status=503, message="Service Unavailable"
+                ),
+                aiohttp.ClientResponseError,
+            ),
+            (
+                lambda: aiohttp.ClientResponseError(
+                    request_info=AsyncMock(), history=(), status=500, message="Internal Server Error"
+                ),
+                aiohttp.ClientResponseError,
+            ),
+            (
+                lambda: aiohttp.ClientConnectorError(AsyncMock(), OSError("Connection refused")),
+                aiohttp.ClientConnectorError,
+            ),
+            (lambda: TimeoutError("Request timeout"), TimeoutError),
+        ],
+        ids=[
+            "aiohttp_503_exhausted",
+            "aiohttp_500_exhausted",
+            "connector_error_exhausted",
+            "timeout_exhausted",
+        ],
+    )
+    @patch("airflow.providers.dbt.cloud.hooks.dbt.aiohttp.ClientSession.get")
+    async def test_get_job_details_retry_with_exhausted_retries(
+        self, get_mock, error_factory, expected_exception
+    ):
+        hook = DbtCloudHook(ACCOUNT_ID_CONN, retry_limit=2, retry_delay=0.1)
+
+        def fail_cm():
+            cm = AsyncMock()
+            cm.__aenter__.side_effect = error_factory()
+            return cm
+
+        get_mock.side_effect = [fail_cm() for _ in range(2)]
+
+        with pytest.raises(expected_exception):
+            await hook.get_job_details(run_id=RUN_ID, account_id=None)
+
+        assert get_mock.call_count == 2
